Get the Accounts a User Follows via the X API (experimental)
Source:R/api-users.R
getUserFollowingAPI.RdRecupera las cuentas que sigue unx usuarix consultando la API GraphQL
interna de X (Following). Requiere una sesion importada con importSessionX().
Usage
getUserFollowingAPI(username, n_users = 100, dir = getwd(), save = TRUE)Examples
if (FALSE) { # \dontrun{
importSessionX(auth_token = "...", ct0 = "...")
getUserFollowingAPI("rstatstweet", n_users = 200)
} # }